@@ -33,13 +33,10 @@ class RxGuiNode(QtCore.QObject):
         if self.gui.is_engine:
             self.is_object = False
             self.node_type = "engine_node"
-        elif self.params()["entity_id"].startswith("eagerx.core.nodes"):
-            node_id = self.params()["entity_id"].split("/")[-1]
-            if node_id in ["ActionsNode", "ObservationsNode", "RenderNode"]:
-                # todo: check if sensors actuators should be added here
-                # todo: change entity_id format to new refactored style
-                self.node_type = node_id.lower()[:-4]
-                self.is_object = False
+        elif name in ["env/actions", "env/observations", "env/render"]:
+            # todo: check if sensors actuators should be added here
+            self.node_type = name.split("/")[-1]
+            self.is_object = False
         else:
             self.node_type = get_yaml_type(self.gui.graph.get_spec(name).params)
         self.allow_remove = True
@@ -230,7 +227,8 @@ class NodeGraphicsItem(GraphicsObject):
         inp = self.node.inputs
         y = self.nameItem.boundingRect().height() + 5
         max_width_inp = 0.0
-        for i, t in inp.items():
+        for i in sorted(inp.keys()):
+            t = inp[i]
             item = t.graphics_item()
             item.setParentItem(self)
             br = self.bounds
@@ -245,7 +243,8 @@ class NodeGraphicsItem(GraphicsObject):
         dy = bounds.height() / (len(out) + 1)
         y = self.nameItem.boundingRect().height() + 5
         max_width_out = 0.0
-        for i, t in out.items():
+        for i in sorted(out.keys()):
+            t = out[i]
             item = t.graphics_item()
             item.setParentItem(self)
             item.setZValue(self.initial_z_value)
@@ -260,8 +259,8 @@ class NodeGraphicsItem(GraphicsObject):
         if y_max > bounds.height() - 5:
             self.bounds = QtCore.QRectF(0, 0, self.bounds.width(), y_max + 6.0)
 
-        if max_width_inp + max_width_out > bounds.width() + 10:
-            self.bounds = QtCore.QRectF(0, 0, max_width_inp + max_width_out + 10.0, self.bounds.height())
+        if max_width_inp + max_width_out > bounds.width() - 10:
+            self.bounds = QtCore.QRectF(0, 0, max_width_inp + max_width_out + 11.0, self.bounds.height())
             self.update_terminals()
         self.update()
 
